package com.zd.laboratory.mapper;

import java.util.List;
import com.zd.laboratory.domain.LabCeditScoreSite;

/**
 * 信用合格分设置Mapper接口
 * 
 * @author zd
 * @date 2021-12-13
 */
public interface LabCeditScoreSiteMapper 
{
    /**
     * 查询信用合格分设置
     * 
     * @param id 信用合格分设置主键
     * @return 信用合格分设置
     */
    public LabCeditScoreSite selectLabCeditScoreSiteById(Long id);

    /**
     * 查询信用合格分设置列表
     * 
     * @param labCeditScoreSite 信用合格分设置
     * @return 信用合格分设置集合
     */
    public List<LabCeditScoreSite> selectLabCeditScoreSiteList(LabCeditScoreSite labCeditScoreSite);

    /**
     * 新增信用合格分设置
     * 
     * @param labCeditScoreSite 信用合格分设置
     * @return 结果
     */
    public int insertLabCeditScoreSite(LabCeditScoreSite labCeditScoreSite);

    /**
     * 修改信用合格分设置
     * 
     * @param labCeditScoreSite 信用合格分设置
     * @return 结果
     */
    public int updateLabCeditScoreSite(LabCeditScoreSite labCeditScoreSite);

    /**
     * 删除信用合格分设置
     * 
     * @param id 信用合格分设置主键
     * @return 结果
     */
    public int deleteLabCeditScoreSiteById(Long id);

    /**
     * 批量删除信用合格分设置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLabCeditScoreSiteByIds(Long[] ids);
}
