package com.zd.laboratory.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import com.zd.common.core.domain.per.PerFun;
import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.laboratory.domain.LabCeditScoreSite;
import com.zd.laboratory.service.ILabCeditScoreSiteService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.web.domain.AjaxResult;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.zd.common.core.web.page.TableDataInfo;

/**
 * 信用合格分设置Controller
 *
 * @author zd
 * @date 2021-12-13
 */
@RestController
@Api(tags = "【信用合格分设置】")
//作者手动加入 ，在接口上加作者@ApiOperationSupport(author = "XXX")
@RequestMapping("/ceditScoreSite")
public class LabCeditScoreSiteController extends BaseController
{
    @Autowired
    private ILabCeditScoreSiteService labCeditScoreSiteService;

    /**
     * 查询信用合格分设置列表
     */
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_CEDITSCORESITE + PerFun.LIST)
    @GetMapping("/list")
    @ApiOperation(value = "查询信用合格分设置列表")
    public TableDataInfo<LabCeditScoreSite> list(LabCeditScoreSite labCeditScoreSite)
    {
        startPage();
        List<LabCeditScoreSite> list = labCeditScoreSiteService.selectLabCeditScoreSiteList(labCeditScoreSite);
        return getDataTable(list);
    }

    /**
     * 导出信用合格分设置列表
     */
    @ApiOperation(value = "导出信用合格分设置列表")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_CEDITSCORESITE + PerFun.EXPORT)
    @Log(title = "信用合格分设置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LabCeditScoreSite labCeditScoreSite) throws IOException
    {
        List<LabCeditScoreSite> list = labCeditScoreSiteService.selectLabCeditScoreSiteList(labCeditScoreSite);
        ExcelUtil<LabCeditScoreSite> util = new ExcelUtil<LabCeditScoreSite>(LabCeditScoreSite.class);
        util.exportExcel(response, list, "信用合格分设置数据");
    }

    /**
     * 获取信用合格分设置详细信息
     */
    @ApiOperation(value = "获取信用合格分设置详细信息")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_CEDITSCORESITE + PerFun.QUERY)
    @GetMapping(value = "/{id}")
    public ResultData<LabCeditScoreSite> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(labCeditScoreSiteService.selectLabCeditScoreSiteById(id));
    }

    /**
     * 新增信用合格分设置
     */
    @ApiOperation(value = "新增信用合格分设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_CEDITSCORESITE + PerFun.ADD)
    @Log(title = "信用合格分设置", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody LabCeditScoreSite labCeditScoreSite)
    {
        return ResultData.result(labCeditScoreSiteService.insertLabCeditScoreSite(labCeditScoreSite));
    }

    /**
     * 修改信用合格分设置
     */
    @ApiOperation(value = "修改信用合格分设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_CEDITSCORESITE + PerFun.EDIT)
    @Log(title = "信用合格分设置", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody LabCeditScoreSite labCeditScoreSite)
    {
        return  ResultData.result(labCeditScoreSiteService.updateLabCeditScoreSite(labCeditScoreSite));
    }

    /**
     * 删除信用合格分设置
     */
    @ApiOperation(value = "删除信用合格分设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_CEDITSCORESITE + PerFun.REMOVE)
    @Log(title = "信用合格分设置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(labCeditScoreSiteService.deleteLabCeditScoreSiteByIds(ids));
    }
}
